#
# spec file for package deepin-terminal
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2020 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           deepin-terminal
Version:        3.2.6
Release:        lp152.3.4
Summary:        Deepin terminal
License:        GPL-3.0-or-later AND GPL-3.0-only
Group:          System/X11/Terminals
URL:            https://github.com/linuxdeepin/deepin-terminal
Source0:        https://github.com/linuxdeepin/deepin-terminal/archive/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE deepin-terminal-system-vte.patch hillwood@opensuse.org - Use vte in system default
Patch0:         deepin-terminal-system-vte.patch
# PATCH-FIX-UPSTREAM deepin-terminal-xcb.vapi-missing-return-statement-at-end-of-subroutine-body.patch
Patch1:         deepin-terminal-xcb.vapi-missing-return-statement-at-end-of-subroutine-body.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gtk-doc
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool >= 0.35.0
BuildRequires:  libxml2-tools
BuildRequires:  readline-devel
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(xcb)
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150100
BuildRequires:  pkgconfig(vte-2.91)
%endif
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(ncurses)
Recommends:     %{name}-lang
Requires:       deepin-menu
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%lang_package

%description
Deepin Terminal is an advanced terminal emulator with workspace, multiple 
windows, remote management, quake mode and other features.

%prep
%autosetup -p1
sed -i 's|return @@PROJECT_PATH@@;|return "%{_datadir}/%{name}";|' project_path.c.in

%build
%cmake -DCMAKE_INSTALL_DIR=%{_prefix} \
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150100
       -DUSE_SYSTEM_VTE=ON \
%endif
       -DCMAKE_C_FLAGS="$RPM_OPT_FLAGS" \
       -DCMAKE_CXX_FLAGS="$RPM_OPT_FLAGS" 
%if 0%{?sle_version} > 150000 && 0%{?is_opensuse}
%cmake_build
%else
make %{?_smp_mflags}
%endif

%install
%cmake_install

%suse_update_desktop_file %{name}
%find_lang %{name}
%fdupes %{buildroot}

%files
%defattr(-,root,root,-)
%doc README.md CHANGELOG.md
%license LICENSE
%dir %{_datadir}/%{name}
%dir %{_libexecdir}/%{name}
%{_bindir}/%{name}
%{_libexecdir}/%{name}/ssh_login.sh
%{_libexecdir}/%{name}/zssh
%{_datadir}/%{name}/style.css
%{_datadir}/%{name}/theme
%{_datadir}/%{name}/image
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop

%files lang -f %{name}.lang

%changelog
* Tue Feb 11 2020 Hillwood Yang <hillwood@opensuse.org>
- Support Leap 15.2
* Sun Nov 10 2019 Marguerite Su <i@marguerite.su>
- add deepin-terminal-xcb.vapi-missing-return-statement-at-end-of-subroutine-body.patch
  * fix TW build errors
- drop deepin-terminal_unbundle_vte.patch, refreshed to be
  deepin-terminal-system-vte.patch
* Sat Jun 15 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.2.6
  * blur under KWin wm support
  * Fix make special password for ssh login works
  * Revert a commit which cause window size grows
  * Fix terminal window drifts after toggling compositor
  * Fix download file opened dialog should modal parent
  * Fix May crash when split terminal window
  * Fix quake window get focus on KWin
* Fri Jun  7 2019 Hillwood Yang <hillwood@opensuse.org>
- Change License to "GPL-3.0-or-later AND GPL-3.0-only".
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Remove nonsense from description.
* Sun May 19 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.2.2.1
  * Support breaks line selection on touchscreen.
  * Auto pull translation files from transifex.
  * Correct a typo.
  * Translation update.
  * Config option for bold_is_bright
  * Fix: Take `QT_FONT_DPI` into consideration.
- Don't apply deepin-terminal_unbundle_vte.patch in leap 15
* Sun Mar 24 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.2.1.1
  * avoid using dpkg-parsechangelog
  * merge po
  * update pot
  * add travis-ci build
  * Fix touch on selection causing deselection
  * Fix zssh "out of pty's" issue on debian stretch w/ vendor lib
  * Update ts file and deepin vendor support
  * backport support for debian stretch
  * use markup text to create layout
  * better theme preview 'eye-candy'
  * theme preview use the correct color'n'text
  * remove line above at titlebar.
  * Fix window button hover state set to hand type.
  * feat: update window titlebar button style
  * fix: open_in_filemanager
  * fix: handle `GLib.Error'
  * fix: github issue #74
  * fix: gtk_box_pack assertion error
  * refactor: remove 3rdparty/ and vapi/
  * fix: github issue #73
  * fix: missing verison info when building the deb
  * fix: unregister menu before recreate menu
  * refactor: match more mono fonts
  * feat: support customized version string
  * generate version information from git
  * fix: support set tab title use OSC escape sequence
  * Adapt lintian
  * add TEST_BUILD configure condition
  * Add customize search engine to right menu.
  * Like XShell, if user set config option 'copy_on_select' to true,
    terminal will copy select text to system clipboard when text is selected.
  * Add github, stackoverflow, duckduckgo in default search engine.
  * Add git ssh link support: mouse hover git link to copy it.
  * Open current directory in file manager.
  * Slow down the opacity adjust speed.
  * Use DBus instead dman to start Deepin Manual, Deepin Manual just will run
    in flatpak runtime in the future.
  * Search improvements, allow to search with enter key and previous/next
    buttons even after initial search panel opening, improved by avently,
    thanks.
  * Search improvements, disabled live search, improved by avently, thanks.
  * Refactory CMakeLists.txt, improved by avently, thanks.
  * Add WenQuanYi in mono font whitelist, WenQuanYi's attribute is incomplete,
    not include spacing attribue.
  * Just reset terminal when exit code match samba error code, other non-zero
    code (such as Ctrl + C etc) don't trigger reset terminal.
  * Refactory code: move prevent event code to Widgets.SpinButton.
  * Prevent scrolling event of Gtk.ComboBoxText and Gtk.SpinButton.
  * Add empathy theme.
  * Fixed spell of README.md, thanks wtz.
  * Add miss dependences in README.md.
  * Add advanced options in README.md.
  * Update copyright year.
  * Update translations.
* Thu Mar  1 2018 hillwood@opensuse.org
- Fix project path.
* Fri Feb  9 2018 hillwood@opensuse.org
- Update to 2.9.2
  * Fixed blur background not work for 4k screen.
* Wed Nov 29 2017 hillwood@opensuse.org
- Update to 2.9.1
  * Add option 'show_highlight_frame', default set to false, it's nosie to
    display highlight frame everytime i select terminal window.
  * Adjust about dialog font size.
  * Adjust progressbar draw coordinate.
  * Upload file to remote server when drag file to remote terminal.
  * Split terminal to login server if current terminal has login.
  * Set 'NO_AT_BRIDGE' environment variable with 1 to dislable accessibility
    dbus warning.
  * Display highlight frame when select different terminal window.
  * Fixed preference dialog widget width problem when use German.
  * Adjust slider button text width to make it can display ip address completely.
  * Add "blur background" option in preference dialog.
  * Update translations.
  * Drag file to remote server if terminal is login.
  * Downgrade zssh version
  * Change get_ssh_script_path path to follow debian policy.
  * Adjust preference dialog font attribute.
  * Downgrade zssh version
  * Change get_ssh_script_path path to follow debian policy.
  * Adjust preference dialog font attribute.
  * Buildin zssh in deepin-terminal, don't need depend zssh in linux distribution
  * Fixed search text color is not correctly when terminal use light theme
  * Add baidu and bing search engine in right menu
  * Synchronous translations
- Add deepin-terminal_unbundle_vte.patch. Use vte in system default.
* Fri Sep 29 2017 hillwood@opensuse.org
- Update to 2.7.0+git20170920
  * Add 'load_theme' option to make new terminal load theme that provide
    by user.
  * Add "New theme terminal" feature: press Ctrl + Alt + num to create new
    theme terminal.
  * Update pot file with new feature: load_theme option and new theme
    terminal window.
  * Make deepin-terminal can compile under vala 0.36.5.
* Fri Sep 29 2017 hillwood@opensuse.org
- Initial package.
